tiled.structures.dataframe.DataFrameStructure
=============================================

.. currentmodule:: tiled.structures.dataframe

.. autoclass:: DataFrameStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataFrameStructure.__init__
      ~DataFrameStructure.from_json
   
   

   
   
   